@@ -113,7 +113,7 @@ class EwaldSummation:
 
         # Compute the correction for a charged cell
         self._charged_cell_energy = - EwaldSummation.CONV_FACT / 2 * np.pi / \
-                                    structure.volume / self._eta * structure.charge ** 2
+            structure.volume / self._eta * structure.charge ** 2
 
     def compute_partial_energy(self, removed_indices):
         """
@@ -250,18 +250,17 @@ class EwaldSummation:
             raise AttributeError(
                 "Forces are available only if compute_forces is True!")
         return self._forces
-        
+
     def get_site_energy(self, site_index):
         """Compute the energy for a single site in the structure
-        
+
         Args:
             site_index (int): Index of site
         ReturnS:
             (float) - Energy of that site"""
         if self._charged:
             warn('Per atom energies for charged structures not supported in EwaldSummation')
-        return np.sum(self._recip[:,site_index]) + np.sum(self._real[:,site_index]) \
-            + self._point[site_index]
+        return np.sum(self._recip[:, site_index]) + np.sum(self._real[:, site_index]) + self._point[site_index]
 
     def _calc_recip(self):
         """
@@ -312,7 +311,7 @@ class EwaldSummation:
             if self._compute_forces:
                 pref = 2 * expval / g2 * oxistates
                 factor = prefactor * pref * (
-                    sreal * np.sin(gr) - simag * np.cos(gr))
+                        sreal * np.sin(gr) - simag * np.cos(gr))
 
                 forces += factor[:, None] * g[None, :]
 
@@ -338,7 +337,7 @@ class EwaldSummation:
 
         for i in range(numsites):
             nfcoords, rij, js, _ = self._s.lattice.get_points_in_sphere(fcoords,
-                                    coords[i], self._rmax, zip_results=False)
+                                                                        coords[i], self._rmax, zip_results=False)
 
             # remove the rii term
             inds = rij > 1e-8
@@ -376,17 +375,17 @@ class EwaldSummation:
     def __str__(self):
         if self._compute_forces:
             output = ["Real = " + str(self.real_space_energy),
-                  "Reciprocal = " + str(self.reciprocal_space_energy),
-                  "Point = " + str(self.point_energy),
-                  "Total = " + str(self.total_energy),
-                  "Forces:\n" + str(self.forces)
-                  ]           
+                      "Reciprocal = " + str(self.reciprocal_space_energy),
+                      "Point = " + str(self.point_energy),
+                      "Total = " + str(self.total_energy),
+                      "Forces:\n" + str(self.forces)
+                      ]
         else:
             output = ["Real = " + str(self.real_space_energy),
-                  "Reciprocal = " + str(self.reciprocal_space_energy),
-                  "Point = " + str(self.point_energy),
-                  "Total = " + str(self.total_energy),
-                  "Forces were not computed"]
+                      "Reciprocal = " + str(self.reciprocal_space_energy),
+                      "Point = " + str(self.point_energy),
+                      "Total = " + str(self.total_energy),
+                      "Forces were not computed"]
         return "\n".join(output)
 
 
@@ -476,7 +475,7 @@ class EwaldMinimizer:
         ewald sum calls recursive function to iterate through permutations
         """
         if self._algo == EwaldMinimizer.ALGO_FAST or \
-                        self._algo == EwaldMinimizer.ALGO_BEST_FIRST:
+                self._algo == EwaldMinimizer.ALGO_BEST_FIRST:
             return self._recurse(self._matrix, self._m_list,
                                  set(range(len(self._matrix))))
 
@@ -490,7 +489,7 @@ class EwaldMinimizer:
         else:
             bisect.insort(self._output_lists, [matrix_sum, m_list])
         if self._algo == EwaldMinimizer.ALGO_BEST_FIRST and \
-                        len(self._output_lists) == self._num_to_return:
+                len(self._output_lists) == self._num_to_return:
             self._finished = True
         if len(self._output_lists) > self._num_to_return:
             self._output_lists.pop()
@@ -547,8 +546,7 @@ class EwaldMinimizer:
             interaction_correction = average_correction * speedup_parameter \
                 + interaction_correction * (1 - speedup_parameter)
 
-        best_case = np.sum(matrix) + np.inner(sums[::-1], fractions - 1) \
-            + interaction_correction
+        best_case = np.sum(matrix) + np.inner(sums[::-1], fractions - 1) + interaction_correction
 
         return best_case
 
