@@ -56,6 +56,7 @@ from pymatgen.core.periodic_table import Specie, Element
 from pymatgen.core.structure import Structure
 from pymatgen.io.vasp.inputs import Incar, Poscar, Potcar, Kpoints, VaspInput
 from pymatgen.io.vasp.outputs import Vasprun, Outcar
+from pymatgen.io.lobster import Lobsterin
 from monty.json import MSONable
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 from pymatgen.symmetry.bandstructure import HighSymmKpath
@@ -225,8 +226,8 @@ class DictSet(VaspInputSet):
 
             If a None value is given, that key is unset. For example,
             {"ENCUT": None} will remove ENCUT from the incar settings.
-        user_kpoints_settings (dict or Kpoints): Allow user to override kpoints 
-            setting by supplying a dict E.g., {"reciprocal_density": 1000}. 
+        user_kpoints_settings (dict or Kpoints): Allow user to override kpoints
+            setting by supplying a dict E.g., {"reciprocal_density": 1000}.
             User can also supply Kpoints object. Default is None.
         user_potcar_settings (dict: Allow user to override POTCARs. E.g.,
             {"Gd": "Gd_3"}. This is generally not recommended. Default is None.
@@ -416,6 +417,7 @@ class DictSet(VaspInputSet):
                 warnings.warn("Relaxation of likely metal with ISMEAR < 1 "
                               "detected. Please see VASP recommendations on "
                               "ISMEAR for metals.", BadInputSetWarning)
+
         return incar
 
     @property
@@ -711,7 +713,7 @@ class MPStaticSet(MPRelaxSet):
         return self
 
     @classmethod
-    def from_prev_calc(cls, prev_calc_dir,  **kwargs):
+    def from_prev_calc(cls, prev_calc_dir, **kwargs):
         """
         Generate a set of Vasp input files for static calculations from a
         directory of previous Vasp run.
@@ -781,7 +783,7 @@ class MPHSEBSSet(MPHSERelaxSet):
             self.reciprocal_density = 50
         else:
             self.reciprocal_density = reciprocal_density or \
-                self.user_kpoints_settings['reciprocal_density']
+                                      self.user_kpoints_settings['reciprocal_density']
 
         self.kpoints_line_density = kpoints_line_density
         self.copy_chgcar = copy_chgcar
@@ -951,7 +953,7 @@ class MPNonSCFSet(MPRelaxSet):
             incar.update({k: v for k, v in self.prev_incar.items()})
 
         # Overwrite necessary INCAR parameters from previous runs
-        incar.update({"IBRION": -1,  "LCHARG": False, "LORBIT": 11,
+        incar.update({"IBRION": -1, "LCHARG": False, "LORBIT": 11,
                       "LWAVE": False, "NSW": 0, "ISYM": 0, "ICHARG": 11})
 
         if self.mode.lower() == 'uniform':
@@ -1688,7 +1690,6 @@ class MVLRelax52Set(DictSet):
     CONFIG = _load_yaml_config("MVLRelax52Set")
 
     def __init__(self, structure, potcar_functional="PBE_52", **kwargs):
-
         if potcar_functional not in ["PBE_52", "PBE_54"]:
             raise ValueError("Please select from PBE_52 and PBE_54!")
 
@@ -1822,7 +1823,6 @@ class MITMDSet(MITRelaxSet):
 
     def __init__(self, structure, start_temp, end_temp, nsteps, time_step=2,
                  spin_polarized=False, **kwargs):
-
         # MD default settings
         defaults = {'TEBEG': start_temp, 'TEEND': end_temp, 'NSW': nsteps,
                     'EDIFF_PER_ATOM': 0.000001, 'LSCALU': False,
@@ -2010,6 +2010,66 @@ class MVLScanRelaxSet(MPRelaxSet):
                                            "NELM": 200})
 
 
+class LobsterSet(MPRelaxSet):
+    CONFIG = _load_yaml_config("MPRelaxSet")
+    """
+    Input set to prepare VASP runs that can be digested by Lobster (See cohp.de)
+
+    Args:
+        structure (Structure): input structure.
+        isym (int): ISYM entry for INCAR, only isym=-1 and isym=0 are allowed
+        ismear (int): ISMEAR entry for INCAR, only ismear=-5 and ismear=0 are allowed
+        reciprocal_density (int): density of k-mesh by reciprocal volume
+        potcar_functional (string): only PBE_54, PBE_52 and PBE are recommended at the moment
+        **kwargs: Other kwargs supported by :class:`DictSet`.
+
+    """
+
+    def __init__(self, structure: Structure, isym=-1, ismear=-5, reciprocal_density=None, potcar_functional="PBE_54",
+                 **kwargs):
+        warnings.warn("Make sure that all parameters are okay! This is a brand new implementation.")
+
+        if not (isym == -1 or isym == 0):
+            raise ValueError("Lobster cannot digest WAVEFUNCTIONS with symmetry")
+        if not (ismear == -5 or ismear == 0):
+            raise ValueError("Lobster usually works with ismear=-5 or ismear=0")
+
+        # newest potcars are preferred
+        super().__init__(structure, potcar_functional=potcar_functional, **kwargs)
+
+        # reciprocal density
+        if self.user_kpoints_settings is not None:
+            if (not reciprocal_density or "reciprocal_density" not in self.user_kpoints_settings):
+                # test, if this is okay
+                self.reciprocal_density = 310
+            else:
+                self.reciprocal_density = reciprocal_density or \
+                                          self.user_kpoints_settings['reciprocal_density']
+        else:
+            if (not reciprocal_density):
+                # test, if this is okay
+                self.reciprocal_density = 310
+            else:
+                self.reciprocal_density = reciprocal_density
+
+        # might need to be adapted in the future
+        ediff_per_atom = 5e-05
+
+        self.isym = isym
+        self.ismear = ismear
+        # predefined basis! Check if the basis is okay! (charge spilling and bandoverlaps!)
+        basis = Lobsterin._get_basis(structure=structure,
+                                     potcar_symbols=self.potcar_symbols)
+        lobsterin = Lobsterin(settingsdict={"basisfunctions": basis})
+        nbands = lobsterin._get_nbands(structure=structure)
+
+        update_dict = {"EDIFF_PER_ATOM": ediff_per_atom, "NSW": 0, "LWAVE": True, "ISYM": isym, "NBANDS": nbands,
+                       "IBRION": -1, "ISMEAR": ismear, "LORBIT": 11, "ICHARG": 0, "ALGO": "Normal"}
+
+        self._config_dict["INCAR"].update(update_dict)
+        self._config_dict["KPOINTS"].update({"reciprocal_density": self.reciprocal_density})
+
+
 def get_vasprun_outcar(path, parse_dos=True, parse_eigen=True):
     path = Path(path)
     vruns = list(glob.glob(str(path / "vasprun.xml*")))
